@@ -81,6 +81,7 @@ void PackageKitBackend::acquireFetching(bool f)
     if ((!f && m_isFetching==0) || (f && m_isFetching==1)) {
         emit fetchingChanged();
     }
+    Q_ASSERT(m_isFetching>=0);
 }
 
 void PackageKitBackend::reloadPackageList()
@@ -260,16 +261,23 @@ void PackageKitBackend::addPackageToUpdate(PackageKit::Transaction::Info info, c
 
 void PackageKitBackend::getUpdatesFinished(PackageKit::Transaction::Exit, uint)
 {
-    PackageKit::Transaction* transaction = PackageKit::Daemon::getDetails(m_updatesPackageId.toList());
-    connect(transaction, SIGNAL(details(PackageKit::Details)), SLOT(packageDetails(PackageKit::Details)));
-    connect(transaction, SIGNAL(errorCode(PackageKit::Transaction::Error,QString)), SLOT(transactionError(PackageKit::Transaction::Error,QString)));
-    connect(transaction, SIGNAL(finished(PackageKit::Transaction::Exit,uint)), SLOT(getUpdatesDetailsFinished(PackageKit::Transaction::Exit,uint)));
+    if (!m_updatesPackageId.isEmpty()) {
+        acquireFetching(true);
+        PackageKit::Transaction* transaction = PackageKit::Daemon::getDetails(m_updatesPackageId.toList());
+        connect(transaction, SIGNAL(details(PackageKit::Details)), SLOT(packageDetails(PackageKit::Details)));
+        connect(transaction, SIGNAL(errorCode(PackageKit::Transaction::Error,QString)), SLOT(transactionError(PackageKit::Transaction::Error,QString)));
+        connect(transaction, SIGNAL(finished(PackageKit::Transaction::Exit,uint)), SLOT(getUpdatesDetailsFinished(PackageKit::Transaction::Exit,uint)));
+    }
 
+    acquireFetching(false);
     emit updatesCountChanged();
 }
 
-void PackageKitBackend::getUpdatesDetailsFinished(PackageKit::Transaction::Exit, uint)
+void PackageKitBackend::getUpdatesDetailsFinished(PackageKit::Transaction::Exit exit, uint)
 {
+    if (exit != PackageKit::Transaction::ExitSuccess) {
+        qWarning() << "Couldn't figure out the updates on PackageKit backend" << exit;
+    }
     acquireFetching(false);
 }
 
