@@ -74,6 +74,8 @@ class MUONPRIVATE_EXPORT PackageKitBackend : public AbstractResourcesBackend
         void getUpdatesDetailsFinished(PackageKit::Transaction::Exit,uint);
 
     private:
+        void checkDaemonRunning();
+        void fetchUpdates();
         void acquireFetching(bool f);
 
         QHash<QString, AbstractResource*> m_packages;
@@ -81,7 +83,6 @@ class MUONPRIVATE_EXPORT PackageKitBackend : public AbstractResourcesBackend
         Appstream::Database m_appdata;
         QList<Transaction*> m_transactions;
         PackageKitUpdater* m_updater;
-        QList<PackageKitResource*> m_upgradeablePackages;
         QPointer<PackageKit::Transaction> m_refresher;
         int m_isFetching;
         QSet<QString> m_updatesPackageId;
